==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/GovernanceBundleCreateRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IAMBundleEntitlement;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GovernanceBundleCreateRequest
 */
@JsonPropertyOrder({ GovernanceBundleCreateRequest.JSON_PROPERTY_DESCRIPTION,
        GovernanceBundleCreateRequest.JSON_PROPERTY_ENTITLEMENTS, GovernanceBundleCreateRequest.JSON_PROPERTY_NAME })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class GovernanceBundleCreateRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DESCRIPTION = "description";
    private String description;

    public static final String JSON_PROPERTY_ENTITLEMENTS = "entitlements";
    private List<IAMBundleEntitlement> entitlements = null;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public GovernanceBundleCreateRequest() {
    }

    public GovernanceBundleCreateRequest description(String description) {

        this.description = description;
        return this;
    }

    /**
     * Get description
     *
     * @return description
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DESCRIPTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDescription() {
        return description;
    }

    @JsonProperty(JSON_PROPERTY_DESCRIPTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDescription(String description) {
        this.description = description;
    }

    public GovernanceBundleCreateRequest entitlements(List<IAMBundleEntitlement> entitlements) {

        this.entitlements = entitlements;
        return this;
    }

    public GovernanceBundleCreateRequest addentitlementsItem(IAMBundleEntitlement entitlementsItem) {
        if (this.entitlements == null) {
            this.entitlements = new ArrayList<>();
        }
        this.entitlements.add(entitlementsItem);
        return this;
    }

    /**
     * Get entitlements
     *
     * @return entitlements
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<IAMBundleEntitlement> getEntitlements() {
        return entitlements;
    }

    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntitlements(List<IAMBundleEntitlement> entitlements) {
        this.entitlements = entitlements;
    }

    public GovernanceBundleCreateRequest name(String name) {

        this.name = name;
        return this;
    }

    /**
     * Get name
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GovernanceBundleCreateRequest governanceBundleCreateRequest = (GovernanceBundleCreateRequest) o;
        return Objects.equals(this.description, governanceBundleCreateRequest.description)
                && Objects.equals(this.entitlements, governanceBundleCreateRequest.entitlements)
                && Objects.equals(this.name, governanceBundleCreateRequest.name);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(description, entitlements, name);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GovernanceBundleCreateRequest {\n");
        sb.append("    description: ").append(toIndentedString(description)).append("\n");
        sb.append("    entitlements: ").append(toIndentedString(entitlements)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/GovernanceBundleCreateRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IAMBundleEntitlement;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GovernanceBundleCreateRequest
 */
@JsonPropertyOrder({ GovernanceBundleCreateRequest.JSON_PROPERTY_DESCRIPTION,
        GovernanceBundleCreateRequest.JSON_PROPERTY_ENTITLEMENTS, GovernanceBundleCreateRequest.JSON_PROPERTY_NAME })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class GovernanceBundleCreateRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DESCRIPTION = "description";
    private String description;

    public static final String JSON_PROPERTY_ENTITLEMENTS = "entitlements";
    private List<IAMBundleEntitlement> entitlements = null;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public GovernanceBundleCreateRequest() {
    }

    public GovernanceBundleCreateRequest description(String description) {

        this.description = description;
        return this;
    }

    /**
     * Get description
     *
     * @return description
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DESCRIPTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDescription() {
        return description;
    }

    @JsonProperty(JSON_PROPERTY_DESCRIPTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDescription(String description) {
        this.description = description;
    }

    public GovernanceBundleCreateRequest entitlements(List<IAMBundleEntitlement> entitlements) {

        this.entitlements = entitlements;
        return this;
    }

    public GovernanceBundleCreateRequest addentitlementsItem(IAMBundleEntitlement entitlementsItem) {
        if (this.entitlements == null) {
            this.entitlements = new ArrayList<>();
        }
        this.entitlements.add(entitlementsItem);
        return this;
    }

    /**
     * Get entitlements
     *
     * @return entitlements
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<IAMBundleEntitlement> getEntitlements() {
        return entitlements;
    }

    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntitlements(List<IAMBundleEntitlement> entitlements) {
        this.entitlements = entitlements;
    }

    public GovernanceBundleCreateRequest name(String name) {

        this.name = name;
        return this;
    }

    /**
     * Get name
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GovernanceBundleCreateRequest governanceBundleCreateRequest = (GovernanceBundleCreateRequest) o;
        return Objects.equals(this.description, governanceBundleCreateRequest.description)
                && Objects.equals(this.entitlements, governanceBundleCreateRequest.entitlements)
                && Objects.equals(this.name, governanceBundleCreateRequest.name);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(description, entitlements, name);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GovernanceBundleCreateRequest {\n");
        sb.append("    description: ").append(toIndentedString(description)).append("\n");
        sb.append("    entitlements: ").append(toIndentedString(entitlements)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
